#!/bin/sh
PRIMER3_DIR=/usr/local/bin
export PRIMER3_DIR
perl mcprimers.pl

